@@ -8,7 +8,11 @@ if (getRversion() < "4.0.0") {
         paste(deparse(expr, width.cutoff, ...), collapse = collapse)
     }
 }
- 
+
+## FIXME: refactor! lmer::lFormula calls expandDoubleVerts(),
+##  but also calls findbars -> findbars_x -> expandDoubleVert
+## maybe expandDoubleVerts
+
 #' expand double-bar RE notation by splitting
 #' @param term a formula term
 #' @rdname formfuns
@@ -34,6 +38,7 @@ expandDoubleVert <- function(term) {
     return(res)
 }
 
+## note: only used by lme4
 ##' From the right hand side of a formula for a mixed-effects model,
 ##' expand terms with the double vertical bar operator
 ##' into separate, independent random effect terms.
@@ -49,12 +54,15 @@ expandDoubleVerts <- function(term)
 {
     expandDoubleVert <- function(term) {
         frml <- formula(substitute(~x,list(x=term[[2]])))
-        ## FIXME: do this without paste and deparse if possible!
+
         ## need term.labels not all.vars to capture interactions too:
         newtrms <- paste0("0+", attr(terms(frml), "term.labels"))
         if(attr(terms(frml), "intercept")!=0)
             newtrms <- c("1", newtrms)
 
+        ## FIXME: do this without paste and deparse if possible!
+        ## see expandDoubleVert()
+        
         as.formula(paste("~(",
                          paste(vapply(newtrms, function(trm)
                                       paste0(trm, "|", deparse(term[[3]])), ""),
@@ -219,8 +227,11 @@ findReTrmClasses <- function() {
 
 toLang <- function(x) parse(text=x)[[1]]
 
-#' apply
+#' apply operator expansion (e.g. a/b -> a + a:b) to a formula term
+#'
 #' @param f a language object (an atom of a formula)
+#' @export
+#' @examples
 #' expandGrpVar(quote(x*y))
 #' expandGrpVar(quote(x/y))
 expandGrpVar <- function(f) {
@@ -296,19 +307,19 @@ esfun <- function(x) {
 } ## esfun def.
 
 
+#' @exportS3Method NULL 
 ## sugar: this returns the operator, whether ~ or something else
-#' @export
 head.formula <- function(x, ...) {
     x[[1]]
 }
 
-#' @export
+#' @exportS3Method NULL 
 head.call <- head.formula
 
-#' @export
+#' @exportS3Method NULL 
 head.language <- head.formula
 
-#' @export
+#' @exportS3Method NULL 
 ## sugar: we can call head on a symbol and get back the symbol
 head.name <- function(x, ...) { x }
 
@@ -389,11 +400,8 @@ findbars_x <- function(term,
                                      op = quote(`|`)),
                               as.name("diag")))
             }
-            if (expand_doublevert_method == "split") {
-                ## need to return *multiple* elements
-                return(lapply(expandDoubleVert(term), fbx))
-            } 
-            stop("unknown doublevert method ", expand_doublevert_method)
+            ## expand_double_vert_method == "split" if we get here
+            return(lapply(expandDoubleVert(term), fbx))
         }
         if (head(term) == as.name("(")) {  ## found (...)
             if (debug) cat("paren term:",deparse(term),"\n")
@@ -423,6 +431,18 @@ findbars_x <- function(term,
 
 }
 
+##' This is a backward-compatible (and especially lme4-compatible) wrapper for findbars_x, which is more flexible/capable.
+##' It extracts the random effects from a formula.
+##'
+##' @param term a formula or piece of a formula
+##' @examples
+##' findbars(~ 1 + (x + y || g))
+##' findbars(~ 1 + (1 | f) + (1 | g))
+##' findbars(~ 1 + (1|h) + (x + y || g))
+##' findbars(~ 1 + (1|Subject))
+#' findbars(~  1 + (1||Subject))
+##' findbars(~ (1||Subject))
+##' findbars(~ 1 + x)
 ##' @rdname formfuns
 ##' @export
 ## lme4::findbars-compatible
@@ -801,6 +821,7 @@ replaceForm <- function(term,target,repl) {
 ##' @examples
 ##' no_specials(findbars_x(~ 1 + s(x) + (f|g) + diag(x|y)))
 ##' no_specials(~us(f|g))
+##' no_specials(~us(f|g, extra_arg))
 ##' @export
 no_specials <- function(term, specials = c("|", "||", "s")) {
     if (is.list(term)) {
@@ -809,7 +830,7 @@ no_specials <- function(term, specials = c("|", "||", "s")) {
     for (ss in specials) {
         if (identical(head(term), as.name(ss))) return(term)
     }
-    if (length(term) == 3) stop("don't know what to do")
+    ## if (length(term) == 3) stop("don't know what to do")
     return(no_specials(term[[2]], specials))
 }
 
